#!/usr/bin/env python
# -*- coding:utf-8 -*-
import sys

import psycopg2
import psycopg2.extras
import json

import fetch_dtc

VERBOSE = False

def getcursor():
    """Récupère un curseur connecté à la base dtc"""
    con = psycopg2.connect(database="dtc")
    cur = con.cursor(cursor_factory=psycopg2.extras.DictCursor)
    return con, cur


def insert(quote):
    """Insère une quote dans la base"""
    if VERBOSE:
        print "INSERTing %s" % quote["id"]
    con, cur = getcursor()
    cur.execute("INSERT INTO quotes (id, date, quote) VALUES (%(id)s, %(date)s, %(quote)s);",
                quote)
    cur.execute("COMMIT;")

def last_inserted():
    """Récupère l'id de la dernière quote enregistrée"""
    con, cur = getcursor()
    cur.execute("SELECT MAX(id) AS maxid FROM quotes;")
    return cur.fetchone()["maxid"]

def get_quotes(first, last=None):
    """Récupère des quotes dans la base."""
    add = ""
    if last != None:
        add = "AND id <= %(last)s"
    con, cur = getcursor()
    req = "SELECT * FROM quotes WHERE id >= %(first)s " + add + ";"
    cur.execute(req, {"first" : first, "last" : last})
    l = cur.fetchall()
    l = [dict(q) for q in l]
    for d in l:
        if d["date"]:
            d["date"] = d["date"].strftime("%F %T")
    return l

def display(liste):
    """Affiche des quotes"""
    t = ("\n" + "_"*80 + "\n").join(["%(id)s (%(date)s)\n%(quote)s" % q for q in liste])
    print t

if __name__ == "__main__":
    import sys
    if sys.argv[1] in ["fetch", "update", "pull"]:
        l = fetch_dtc.getquotes()
        last = last_inserted()
        for q in l:
            if q["id"] > last:
                insert(q)
    else:
        id = int(sys.argv[1])
        try:
            id2 = int(sys.argv[2])
        except ValueError:
            if sys.argv[2] in ["+", "_"]:
                id2 = None
            else:
                print "Le deuxième paramètre doit être un entier ou '+'"
        except IndexError:
            id2 = id
        quotes = get_quotes(first=id, last=id2)
        if "--json" in sys.argv:
            print json.dumps(quotes)
        else:
            display(quotes)
